@@ -6,7 +6,7 @@
 #   Please read the COPYRIGHT and LICENSE files of the package
 ####################################################################
 
-__version__ = "1.0.0"
+__version__ = "1.0.1"
 
 __appname__ = "MyGNUHealth"
 
@@ -18,7 +18,7 @@ __author__ = "Luis Falcon"
 
 __email__ = "info@gnuhealth.org"
 
-__download_url__ = 'https://ftp.gnu.org/gnu/health'
+__download_url__ = 'https://ftp.gnu.org/gnu/health/mygnuhealth'
 
 __license__ = "GPL v3+"
 __copyright__ = "Copyright 2008-2021 GNU Solidario"
